@@ -2,5 +2,8 @@ from FreeTAKServer.controllers.configuration.MainConfig import MainConfig
 
 class DatabaseConfiguration:
     DataBasePath = MainConfig.DBFilePath
-    DataBaseType = str('sqlite:///')
-    DataBaseConnectionString = str(DataBaseType+DataBasePath)
\ No newline at end of file
+    if MainConfig.DataBaseType == "SQLite":
+        DataBaseType = str('sqlite:///')
+    elif MainConfig.DataBaseType == "MySQL":
+        DataBaseType = str('mysql://')
+    DataBaseConnectionString = str(DataBaseType+DataBasePath)
