@@ -12,6 +12,6 @@ class ExCheck(Base):
     __tablename__ = 'ExCheck'
     PrimaryKey = Column(Integer, primary_key = True, autoincrement=True)
     timestamp = Column(DateTime)
-    creatorUid = Column(String)
+    creatorUid = Column(String(100))
     checklist = relationship("ExCheckChecklist", backref='template')
     data = relationship("ExCheckData", uselist=False, cascade="all, delete", backref="ExCheck")
